var languageNames = {
"en-US": "Английски (САЩ)",
"sq": "Албански",
"am": "Амхарски",
"ar": "Арабски",
"ast": "Астурски",
"bn": "Бенгалски",
"bn-IN": "Бенгалски (Индия)",
"bs": "Босненски",
"bg": "Български",
"ca": "Каталонски",
"ca-valencia": "Catalan (Valencia)",
"zh-CN": "Китайски (опростен)",
"zh-TW": "Китайски (традиционен)",
"hr": "Хърватски",
"cs": "Чешки",
"da": "Датски",
"nl": "Нидерландски",
"dz": "Дзонха",
"en-GB": "Английски (Обединено кралство)",
"en-ZA": "Английски (Южна Африка)",
"eo": "Есперанто",
"et": "Естонски",
"eu": "Баски",
"fi": "Финландски",
"fr": "Френски",
"gl": "Галисийски",
"ka": "Грузински",
"de": "Немски",
"el": "Гръцки",
"gu": "Гуджарати",
"he": "Иврит",
"hi": "Хинди",
"hu": "Унгарски",
"id": "Индонезийски",
"is": "Исландски",
"it": "Италиански",
"ja": "Японски",
"km": "Кхмерски",
"ko": "Корейски",
"lo": "Лаоски",
"lv": "Латвийски",
"lt": "Литовски",
"mk": "Македонски",
"ne": "Непалски",
"nn": "Норвежки, ниношк",
"nb": "Норвежки, букмол",
"om": "Оромо",
"pl": "Полски",
"pt": "Португалски",
"pt-BR": "Portuguese (Brazil)",
"ro": "Румънски",
"ru": "Руски",
"sid": "Сидама",
"si": "Синхала",
"sk": "Словашки",
"sl": "Словенски",
"dsb": "Sorbian (Lower)",
"hsb": "Sorbian (Upper)",
"es": "Испански",
"sv": "Шведски",
"tg": "Таджикски",
"ta": "Тамилски",
"bo": "Тибетски",
"tr": "Турски",
"ug": "Уйгурски",
"uk": "Украински",
"vi": "Виетнамски",
};
